[jboss-cvs] JBossAS SVN: r85118 - projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/profileservice/spi.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Mon Mar 2 09:53:01 EST 2009


Author: emuckenhuber
Date: 2009-03-02 09:53:00 -0500 (Mon, 02 Mar 2009)
New Revision: 85118

Modified:
   projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/profileservice/spi/DeploymentRepository.java
Log:
update javadoc

Modified: projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/profileservice/spi/DeploymentRepository.java
===================================================================
--- projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/profileservice/spi/DeploymentRepository.java	2009-03-02 14:48:46 UTC (rev 85117)
+++ projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/profileservice/spi/DeploymentRepository.java	2009-03-02 14:53:00 UTC (rev 85118)
@@ -98,12 +98,12 @@
     * Upload raw deployment content to a profile repository. This does not make
     * the deployment available to getDeployments or getModifiedDeployments
     * 
     * @param vfsPath - the full vfs path of the deployment 
     * @param contentIS - the input stream for the deployment contents
     * @throws IOException
     * @return the unique name of the deployment in the repository
     */
-   String addDeploymentContent(String vfsPath, InputStream contentIS)
+   String addDeploymentContent(String name, InputStream contentIS)
       throws IOException;
 
    /**
@@ -119,59 +119,59 @@
    /**
     * lock deployment content and exclude it from modified deployment checks.
     * 
     * @param vfsPath - the full vfs path of the deployment
     * @return the deployment content flags, {@linkplain DeploymentContentFlags}
     */
-   int lockDeploymentContent(String vfsPath);
+   int lockDeploymentContent(String name);
    /**
     * Unlock a previously locked deployment content.
     * 
     * @param vfsPath - the full vfs path of the deployment
     * @return the deployment content flags, {@linkplain DeploymentContentFlags}
     */
-   int unlockDeploymentContent(String vfsPath);
+   int unlockDeploymentContent(String name);
 
    /**
     * Get the status flags for the deployment path
     * 
     * @param vfsPath - the full vfs path of the deployment
     * @return the deployment content flags, {@linkplain DeploymentContentFlags}
     */
-   int getDeploymentContentFlags(String vfsPath);
+   int getDeploymentContentFlags(String name);
    /**
     * Set one or more flags for the deployment.
     * @see #clearDeploymentContentFlags(String)
     * 
     * @param vfsPath - the full vfs path of the deployment
     * @param flags - the deployment content flags, {@linkplain DeploymentContentFlags}
     */
-   int setDeploymentContentFlags(String vfsPath, int flags);
+   int setDeploymentContentFlags(String name, int flags);
    /**
     * Clear one or more flags for the deployment. This ands the compliment of
     * the flags argument into the existing content flags and returns the result.
     * 
     * @param vfsPath - the full vfs path of the deployment
     * @param flags - the deployment content flags, {@linkplain DeploymentContentFlags}
     */
-   int clearDeploymentContentFlags(String vfsPath, int flags);
+   int clearDeploymentContentFlags(String name, int flags);
    /**
     * Does a deployment content have the indicated flag.
     * 
     * @param vfsPath - the full vfs path of the deployment
     * @param flags - the deployment content flags, {@linkplain DeploymentContentFlags}
     * @return true if the content flags contains the flag, false otherwise.
     */
-   boolean hasDeploymentContentFlags(String vfsPath, int flag);
+   boolean hasDeploymentContentFlags(String name, int flag);
 
    /**
     * Add a deployment
     * 
     * @param vfsPath the path
     * @param deployment the deployment
     * deployment is loaded
     * @throws Exception for any error
     */
-   void addDeployment(String vfsPath, ProfileDeployment deployment)
+   void addDeployment(String name, ProfileDeployment deployment)
       throws Exception;
 
    /**
@@ -187,11 +187,11 @@
    /**
     * Remove a deployment
     * 
     * @param vfsPath - the full vfs path of the deployment
     * @return the removed deployment
     * @throws Exception for any error
     */
-   ProfileDeployment removeDeployment(String vfsPath) throws Exception;
+   ProfileDeployment removeDeployment(String name) throws Exception;
 
    /**
     * Get all deployments defined in this profile
@@ -98,12 +98,12 @@
     * the deployment available to getDeployments or getModifiedDeployments
     * 
-    * @param vfsPath - the full vfs path of the deployment 
+    * @param name - the full vfs path of the deployment 
     * @param contentIS - the input stream for the deployment contents
     * @throws IOException
@@ -119,59 +119,59 @@
     * lock deployment content and exclude it from modified deployment checks.
     * 
-    * @param vfsPath - the full vfs path of the deployment
+    * @param name - the full vfs path of the deployment
     * @return the deployment content flags, {@linkplain DeploymentContentFlags}
     */
@@ -119,59 +119,59 @@
     * Unlock a previously locked deployment content.
     * 
-    * @param vfsPath - the full vfs path of the deployment
+    * @param name - the full vfs path of the deployment
     * @return the deployment content flags, {@linkplain DeploymentContentFlags}
     */
@@ -119,59 +119,59 @@
     * Get the status flags for the deployment path
     * 
-    * @param vfsPath - the full vfs path of the deployment
+    * @param name - the full vfs path of the deployment
     * @return the deployment content flags, {@linkplain DeploymentContentFlags}
     */
@@ -119,59 +119,59 @@
     * @see #clearDeploymentContentFlags(String)
     * 
-    * @param vfsPath - the full vfs path of the deployment
+    * @param name - the full vfs path of the deployment
     * @param flags - the deployment content flags, {@linkplain DeploymentContentFlags}
     */
@@ -119,59 +119,59 @@
     * the flags argument into the existing content flags and returns the result.
     * 
-    * @param vfsPath - the full vfs path of the deployment
+    * @param name - the full vfs path of the deployment
     * @param flags - the deployment content flags, {@linkplain DeploymentContentFlags}
     */
@@ -119,59 +119,59 @@
     * Does a deployment content have the indicated flag.
     * 
-    * @param vfsPath - the full vfs path of the deployment
+    * @param name - the full vfs path of the deployment
     * @param flags - the deployment content flags, {@linkplain DeploymentContentFlags}
     * @return true if the content flags contains the flag, false otherwise.
@@ -119,59 +119,59 @@
     * Add a deployment
     * 
-    * @param vfsPath the path
+    * @param name - the full vfs path of the deployment
     * @param deployment the deployment
     * deployment is loaded
@@ -187,11 +187,11 @@
     * Remove a deployment
     * 
-    * @param vfsPath - the full vfs path of the deployment
+    * @param name - the full vfs path of the deployment
     * @return the removed deployment
     * @throws Exception for any error




More information about the jboss-cvs-commits mailing list